#include "stm32f303xx.h"
#include "spi1.h"
#include "serial.h"
#include "l3gd20.h"
void delay(int dly)
{
  while( dly--);
}

void configPins()
{
	// Power up PORTE, PORTA	
	RCC_AHBENR |= BIT21+BIT17;
	// Make PORTE LED bits outputs
	GPIOE_MODER |= BIT30+BIT28+BIT26+BIT24+BIT22+BIT20+BIT18+BIT16;
}
void initClock()
{
	// Assumption: Using HSE clock (8MHz)
	// This clock is provided by the STLink debug interface
	// PLL is driven by HSE = 8MHz
	// Multiply x 9 = 72MHz
	
	// Must set flash latency (2 wait states) to allow
	// for higher speed clock	
	FLASH_ACR |= 2; // add two wait states
	
	RCC_CR &= ~BIT24; // turn off PLL
	delay(10);	
	RCC_CFGR |= ((0x07) << 18);	// PLL multiply = 9
	RCC_CFGR |= BIT16;  // select HSE as PLL input
	RCC_CFGR |= BIT10;  // APB1 Clock = HCLK/2 (36MHz)
	RCC_CR |= BIT18 + BIT16; // Turn on HSE and set HSEBYP
	delay(10);
	RCC_CR |= BIT24; // turn on PLL
	delay(10);
	RCC_CFGR |= BIT1;  // switch to PLL as clock
}

int main()
{	
	int ygyro;
	int status;
	initClock();
	configPins();
	initSPI1();
	initUART(115200);
	initGyro();
	eputs("Ready\r\n");
	while(1)
	{			
		status=0;
		// Wait for Data Ready (INT2/PE1)
		while ( (GPIOE_IDR & BIT1)==0);
		ygyro = ReadGyroRegister(OUT_Y_H);
		ygyro = ygyro << 8;
		ygyro = ygyro + ReadGyroRegister(OUT_Y_L);
		eputShort(ygyro);
		eputs("\n");		
		delay(10000);
	}
	return 0;
}








